@@ -24,23 +24,8 @@
 #include <sys/ioctl.h>
 #include <fcntl.h>
 #include <errno.h>
-#include <mntent.h>
 
-#define MD_MAJOR 9
-#include <asm/types.h>
-
-#define MD_RESERVED       0UL
-#define LINEAR            1UL
-#define RAID0             2UL
-#define RAID1             3UL
-#define RAID5             4UL
-#define TRANSLUCENT       5UL
-#define HSM               6UL
-#define MULTIPATH         7UL
-#define MAX_PERSONALITY   8UL
-
-#include "md_p.h"
-#include "md_u.h"
+#include "md-int.h"
 
 typedef int kdev_t;
 #include <linux/unistd.h>
@@ -63,12 +48,4 @@ extern int do_quiet_flag;
 #define OUT(x...) do { if (!do_quiet_flag) fprintf(stderr,##x); } while (0)
 #define ERR(x...) fprintf(stderr,##x)
 
-/*
- * Our supported algorithms
- */
-#define RAID5_ALGORITHM_LEFT_ASYMMETRIC       0
-#define RAID5_ALGORITHM_RIGHT_ASYMMETRIC      1
-#define RAID5_ALGORITHM_LEFT_SYMMETRIC        2
-#define RAID5_ALGORITHM_RIGHT_SYMMETRIC       3
-
 #endif
