@@ -87,17 +87,16 @@ static int process_entry (char *par, char *val_s)
 	array = &cfg->array;
 	if (strcmp(par, "raid-level") == 0) {
 		if (val == -1) {
+			val = -3;
 			if (!strcmp(val_s, "linear"))
 		    		val = -1;
 			if (!strcmp(val_s, "translucent"))
 		    		val = -2;
-			if (!strcmp(val_s, "hsm"))
+			if (!strcmp(val_s, "lvm"))
 		    		val = -3;
-			if (!strcmp(val_s, "multipath"))
-		    		val = -4;
 		}
 		if (val != 4 && val != 5 && val != 1 && val != -1 &&
-			val != -2 && val != -3 && val != -4 && val != 0) {
+				val != -2 && val != -3 && val != 0) {
 			fprintf(stderr, "raid level %d not supported\n", val);
 			return 1;
 		}
@@ -118,7 +117,7 @@ static int process_entry (char *par, char *val_s)
 		array->param.not_persistent = 1-val;
 		return 0;
 	} else if (strcmp(par, "nr-spare-disks") == 0) {
-		if ((array->param.level < 1) && (array->param.level != -4) && val) {
+		if (array->param.level < 1 && val) {
 			fprintf(stderr, "nr-spare-disks must be zero for raid level %d\n", array->param.level);
 			return 1;
 		}
@@ -171,7 +170,7 @@ static int process_entry (char *par, char *val_s)
 		array->disks[i].raid_disk = val;
 		return 0;
 	} else if (strcmp(par, "spare-disk") == 0) {
-		if ((array->param.level != 5) && (array->param.level != 4) && (array->param.level != 1) && (array->param.level != -4)) {
+		if ((array->param.level != 5) && (array->param.level != 4) && (array->param.level != 1)) {
 			fprintf(stderr, "spare-disk not supported for raid level %d\n", array->param.level);
 			return 1;
 		}
