@@ -14,14 +14,14 @@ extern int parse_config (FILE *fp);
 extern char *parity_algorithm_table[];
 
 typedef struct md_raid_info {
-	mdu_array_info_t param;
-	mdu_disk_info_t disks[MD_SB_DISKS];
+	md_array_info_t param;
+	md_disk_info_t disks[MD_SB_DISKS];
 } md_raid_info_t;
 
 typedef struct md_cfg_entry {
 	md_raid_info_t array; 
 	char *device_name[MD_SB_DISKS];
-	__u32 sb_block_offset[MD_SB_DISKS];
+	md_u32 sb_block_offset[MD_SB_DISKS];
 	char *md_name;
 	struct md_cfg_entry *next;
 } md_cfg_entry_t;
